=======
History
=======

0.5.3 (2021-04-09)
------------------

* Reconfigure travis-ci

0.5.2 (2021-04-09)
------------------

* Add Zenodo badge to README
* Remove remaining references to uk-boards
* Update dependencies

0.5.1 (2021-03-08)
------------------

* Add utility for attaching auxilary data to nodes

0.5.0 (2020-12-20)
------------------

* Add classes for joint queries of companies and charities
* Fix issues with Companies House pagination
* Change library name from uk-boards to ukboards following PEP-8
* Alpha-level customisation of networkx JSON network format
* Options for adding geospatial data from postcodes.io

0.4.0 (2020-01-07)
------------------

* Refactor Companies House queries into separate query functions
* Add a CompanyNetworkClient class for cacheable network queries

0.3.0 (2019-12-18)
------------------

* Add Charity Commission API querying via zeep library
* Include Charity Commision API specification
* Refactor command line interface

0.2.0 (2019-11-18)
------------------

* First use of bump2version

0.1.4 (2019-11-18)
------------------

* Fix PyPI versioning

0.1.3 (2019-11-18)
------------------

* Release on PyPI

0.1.2 (2019-11-17)
------------------

* Enable basic command line query of Companies House
* Enable codecov

0.1.1 (2019-11-13)
------------------

* Improve function and variable names
* Expand docstring of companies_house_query
* Expand type hinting
* pytest-remotedata plugin test for optional real query test

0.1.0 (2019-11-11)
------------------

* First release on PyPI.
* Basic tests of querying from companies house
